pub enum ParseError {
InvalidLength {
expected: usize,
actual: usize,
},
InvalidCharacter(u8),
}Expand description
An error that can occur when parsing a string into a Nano ID.
Variants
InvalidLength
The length of the provided value is not equal to the expected length.
InvalidCharacter(u8)
The provided value contains a character that is not in the alphabet.